# include <clientapi.h>
# include <mapapi.h>
# include <options.h>

# include "joincheck.h"

int main( int argc, char** argv )
{
	ClientApi client;
	Error e;
	JoinCheck check( &client, &e );
	Options opts;

	argc--;
	argv++;

	ErrorId usage = { E_FAILED,
	    "Usage: joincheck [ -b branch -c client -u user -v ]" };
	opts.Parse( argc, argv, "u:b:c:v", OPT_NONE, usage, &e );

	client.SetProtocol( "tag", "" );
	client.Init( &e );
	if ( e.Test() )
	{
	    check.Message( &e );
	    return 1;
	}
	
	check.LoadProtect( opts['u'] );
	check.LoadBranch( opts['b'] );
	check.LoadClient( opts['c'] );

	client.Final( &e );
	if ( e.Test() )
	{
	    check.Message( &e );
	    return 1;
	}

	check.DoJoins();
	MapApi *j = check.FullJoin();

	printf( "Joined map size: %d lines\n", j->Count() );
	printf( "Most wild line:  %d wildcards\n", check.MaxWild( j ) );

	if ( opts['v'] )
	{
	    printf( "\nJoined map:\n" );
	    check.DumpView( j );
	}

	return 0;
}
